import os
from pathlib import Path
from typing import Final

import typer
from beni import bcolor, bfile, bfunc, bstore, btask
from beni.bqiniu import QiniuBucket


app: Final = btask.newSubApp('bin 工具')


@app.command()
@bfunc.syncCall
async def init(
    ak: str = typer.Argument(..., help="七牛云账号AK"),
    sk: str = typer.Argument(..., help="七牛云账号SK"),
):
    '初始化七牛云服务'
    await bstore.set(__file__, (ak, sk))


@app.command()
@bfunc.syncCall
async def download(
    names: str = typer.Argument(None, help="如果有多个使用,分割"),
    file: Path = typer.Option(None, '--file', '-f', help="文件形式指定参数，行为单位"),
    output: Path = typer.Option(None, '--output', '-o', help="本地保存路径"),
):
    '从七牛云下载执行文件'
    try:
        (ak, sk) = await bstore.get(__file__)
    except:
        return bcolor.printRed('请先执行 beni bin init 进行初始化')
    bucketName = 'pytask'
    bucketUrl = 'http://qiniu-cdn.pytask.com'
    if output is None:
        output = Path(os.curdir)
    output = output.resolve()
    bucket = QiniuBucket(bucketName, bucketUrl, ak, sk)
    targetList: list[str] = []
    if names:
        targetList.extend(names.split(','))
    if file:
        content = await bfile.readText(Path(file))
        targetList.extend(content.split('\n'))
    targetList = [x.strip() for x in targetList]
    targetList = [x for x in targetList if x]
    for target in targetList:
        binFile = output / target
        if binFile.exists():
            bcolor.printYellow(f'已存在 {binFile}')
        else:
            key = f'bin/{target}.zip'
            await bucket.downloadPrivateFileUnzip(key, output)
            bcolor.printGreen(f'added  {binFile}')
